#ifndef PYTHONIC_INCLUDE_NUMPY_NEGATIVE_ACCUMULATE_HPP
#define PYTHONIC_INCLUDE_NUMPY_NEGATIVE_ACCUMULATE_HPP

#define UFUNC_NAME negative
#include "pythonic/include/numpy/ufunc_accumulate.hpp"

#endif
